@@ -8,8 +8,8 @@ namespace dplyr {
   public:
     typedef typename Processor::STORAGE STORAGE ;
     
-    TypedProcessor( SEXP data, const char* cl ) : proc(data), classes(cl) {}
-    TypedProcessor( SEXP data, CharacterVector classes_ ) : proc(data), classes(classes_) {}
+    TypedProcessor( SEXP data_, const char* cl ) : proc(data_), classes(cl), data(data_) {}
+    TypedProcessor( SEXP data_, CharacterVector classes_ ) : proc(data_), classes(classes_), data(data_) {}
     
     virtual SEXP process(const Rcpp::GroupedDataFrame& gdf ) {
       return promote( proc.process(gdf) ) ;
@@ -25,10 +25,12 @@ namespace dplyr {
     
   private:
     Processor proc ;
-    CharacterVector classes ;  
+    CharacterVector classes ;
+    SEXP data ;
     
     inline SEXP promote(SEXP obj){
       RObject res(obj) ;
+      copy_attributes(res, data) ; 
       res.attr("class") = classes ;
       return res ;
     }
