@@ -35,7 +35,11 @@
 #include <dplyr/Result/Rank.h>
 #include <dplyr/Result/ConstantResult.h>
 
+#include <dplyr/Result/Mutater.h>
 #include <dplyr/Result/Lead.h>
 #include <dplyr/Result/Lag.h>
+#include <dplyr/Result/CumSum.h>
+#include <dplyr/Result/CumMin.h>
+#include <dplyr/Result/CumMax.h>
 
 #endif
