@@ -1,12 +1,13 @@
 #ifndef dplyr_tools_tools_H
 #define dplyr_tools_tools_H
 
-#include <tools/type_name.h>
+#include <tools/DotsOf.h>
 #include <tools/Call.h>
 #include <tools/hash.h>
 #include <tools/delete_all.h>
 #include <tools/ListOf.h>
 #include <tools/collapse.h>
+#include <tools/get_single_class.h>
 #include <tools/SlicingIndex.h>
 #include <tools/ShrinkableVector.h>
 #include <tools/wrap_subset.h>
